aboutsummaryrefslogtreecommitdiff
path: root/webAO
diff options
context:
space:
mode:
authorsD <stoned@derpymail.org>2019-12-20 20:16:25 +0100
committersD <stoned@derpymail.org>2019-12-20 20:16:25 +0100
commite7092155ec274b78057c6df6dcc52ee61d448ed8 (patch)
treebc2add224393728e0d3ed4f521d0fa2f06dcad94 /webAO
parent7aa1164bfec34c7fcb3f0091303b3d1c3c027995 (diff)
parent7346fc67a2d5c976af0b643ad11600b220f3baf6 (diff)
Merge branch 'master' of https://github.com/AttorneyOnline/webAO
Diffstat (limited to 'webAO')
-rw-r--r--webAO/client.js13
1 files changed, 11 insertions, 2 deletions
diff --git a/webAO/client.js b/webAO/client.js
index 2682456..fd82cc7 100644
--- a/webAO/client.js
+++ b/webAO/client.js
@@ -1634,7 +1634,7 @@ async function fileExists(url) {
/**
* Changes the viewport background based on a given position.
*
* Valid positions: `def, pro, hld, hlp, wit, jud`
* @param {string} position the position to change into
*/
async function changeBackground(position) {
@@ -1670,8 +1670,17 @@ async function changeBackground(position) {
bg: "judgestand.png",
desk: null,
speedLines: "prosecution_speedlines.gif"
+ },
+ jur: {
+ bg: "jurystand.png",
+ desk: { ao2: "jurydesk.png", ao1: "estrado.png" },
+ speedLines: "defense_speedlines.gif"
+ },
+ sea: {
+ bg: "seancestand.png",
+ desk: { ao2: "seancedesk.png", ao1: "estrado.png" },
+ speedLines: "prosecution_speedlines.gif"
}
- // TODO: add the new seance and jury positions
};
const { bg, desk, speedLines } = positions[position];
@@ -1634,7 +1634,7 @@ async function fileExists(url) {
* Changes the viewport background based on a given position.
*
- * Valid positions: `def, pro, hld, hlp, wit, jud`
+ * Valid positions: `def, pro, hld, hlp, wit, jud, jur, sea`
* @param {string} position the position to change into
*/